bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 24. Aventiure
___________________________________________________
| ### <Do> Ecel zv dem Rine sine boten sande ### do flvgen disiv mære von lande ze lande ### mit boten harte snellen er bat vnd ovch gebot ### zv siner hohgecite des holte maniger da den tot ### Di boten dannen fvren vzer Hivnen lant ### zv den Bvfgonden dar waren si gesant ### nach drin edeln kvenegen vnd ovch nach ir man ### si solden chomen Ecele des man do gahen began
###### 1421 | ### Hinze Bechelaren chomen si geritten ### da diente man in gerne daz enwart da niht vermitten ### Rvedeger sinen dienest enbot vnd Gotelint ### bi in hin [361a] hinze Rine vnd ovch ir beider liebez chint
| ### Sine liezens ane gabe von in niht scheiden dan ### daz deste baz gefveren di Ecelen man ### Vten vnd ir chinden enbot do Rvedeger ### sine heten in so wæge deheinen margraven mer
###### 1423 | ### <Si> enbvten ovch Prvnhilte dienest vnd gvt ### stætechliche triwe vnd willigen mvot ### do si di rede vernamen di boten wolden varn ### si bat div margavinne got von himele bewarn
###### 1424 | ### ê daz di boten chomen wol dvrch Peyrlant ### Wærbel der vil snelle den gvten bisschoff vant ### waz der do sinen frivnden hince Rine enbot ### daz ist mir niht gewizen niwan sin golt also rot
| ### Gap er den boten ze minne riten er si lie ### do sprach der <bissof> Bilgrim vnde sold ich si sehen hie ### mir wære wol ce mvte di swester svene min ### wand ich mach vil selten zv zin chomen an den Rin
###### 1426 | ### Welhe wæge si fveren ce Rine dvrch div lant ### des chan ich niht bescheiden ir silber vnt gewant ### daz nam in niemen man vorht ir herren zorn ### ia was gewaltech der edele chvnech wol geborn
###### 1427 | ### Inner tagen zwelfen chomens an den Rin ### ze Wormez zv dem lande Wærbel vnd Swemmelin ### do sagt man div mære den chvenegen vnd ir man ### da chomen boten vremde Gventher do vragen began
| ### Do sprach der vogt von Rine wer tvt vns daz bechant ### von wannen dise vremden riten in daz lant ### daz enwesse niemen vnze daz si sach ### Hagen von Tronege do ce Gventhern sprach
###### 1429 | ### Vns choment niwiv mære des wil ich iv veriehen ### di Eceln videlære di han ich hie gesehen ### si hat iwer swester gesendet an den Rin ### si sveln vns dvrch ir herren groze willechomen sin
###### 1430 | ### Si ritten al bereite fver den palas dan ### ez gefvren nie herlicher fversten spileman ### des chveneges ingesinde enpfiengen sa cehant ### man gap in schoen herberge vnt hiez behalten ir gewant
###### 1431 | ### Ir reisechleider waren rich vnd so wol getan ### ia mohten si mit eren fver [361b] den kvenich gan ### deren wolden si niht mere da ce hove tragen ### ob ir iemen rvchte di boten hiezen iz da sagen
###### 1432 | ### In der selben maze man ovch livte vant ### di ez vil gerne namen den wart ez gesant ### do leiten an di geste verre bezer wat ### als ez boten chvenege ce tragen herliche stat
###### 1433 | ### Do gie mit vrlovbe da der kvenech saz ### daz Eceln gesinde gerne sach man daz ### Hagen zvetechliche gegen den boten spranch ### vnt enpfie si minnechliche des sageten im di knappen danch
| ### Dvrch div chvnden mære vragen er began ### wi sich Ecel gehabte vnd sine man ### do sprach der videlære daz lant gestvnt ni baz ### noch so vro di livte nv wizzet endechliche daz
###### 1435 | ### Si giengen zv dem wirte der palas der was vol ### do enpfie man di geste so man von rehte sol ### so gvetlichez grvezen in ander chvenige lant ### Wærbel vil der recken da bi Gvnthern vant
###### 1436 | ### Der chvenech gezogenliche grvzen si began ### sit willechomen ir beide ir Hivnen spilman ### vnd iwer hergesellen hat ivch her gesant ### Ecel der vil riche zv der Bvrgonden lant
| ### Si nigen dem chvnige do sprach Wærbelin ### dir enbivtet holden dienest der liebe herre min ### vnd Criemhilt din swester her in dize lant ### si habent vns iv recken vf gvte triwe gesant
###### 1438 | ### Do sprach der kvenech riche der mære bin ich vro ### wi gehabt sich Ecel so vragt der degen so ### vnd Criemhilt min swester vzzer Hivnen lant ### do sprach der videlære div mære tvn ich iv bechant
###### 1439 | ### daz sich noch nie gehabten deheine livte baz ### danne si sich gehabent beide wizzet daz ### vnd allez ir gedigene di mage vnd ovch ir man ### si vrevten sich der verte do wir schieden von dan
| ### Genade siner dieneste di er mir enboten hat ### vnd miner swester sit ez also stat ### daz si lebent mit frevden dr kvenech vnd sine man ### wand ich doh der mære gefragt sorgende han
###### 1441 | ### Di zwene ivnge chvenege di waren ovch nv chomen ### si heten disiv mære alrerst do vernomen ### dvrch siner swester liebe di boten gerne sach ### Giselher der ivnge zv zin minnechlichen sprach [362a]
###### 1442 | ### Ir boten <soldet> vns groze willechome sin ### ob ir dicher woldet her riten an den Rin ### ir fvendet hie di frivnde di ir gerne moehtet sehen ### iv solde hie ce lande vil wenich leides geschehen
| ### Wir <trvwen> iv aller eren sprach do Swemmelin ### ine chonde iv niht bedivten mit den sinnen min ### wi rehte minnechlichen iv Ecel enboten hat ### vnt iwer edel swester der dinch in hohen eren stat
###### 1444 | ### Genade vnde triwe mant ivh des kveneges wip ### vnt daz ir ie was wæge iwer herce vnt iwer lip ### vnt ce vorderste dem chvenege sin wir her gesant ### daz ir gervchet riten in daz Eceln lant
###### 1445 | ### Daz wir ivch des bæten vil vast vns daz gebot ### Ecel der riche iv allen daz enbot ### ob ir <ivch> iwer swester niht sehen woldet lan ### so wold er doch gerne wizzen waz er iv hete getan
| ### Daz ir in also vremdet vnt ovch siniv lant ### ob <iv> div chveneginne wære ni bechant ### so moeht er doch verdienen daz ir in rvchet sehen ### swenne daz ergienge so wær im liebe geschehen
###### 1447 | ### Do sprach der chvenech Gvnther veber dise siben naht ### so chvend ich div mære wes ich mich han bedaht ### mit den minen frivnden di wile svlt ir gan ### in iwer herberge vnd svelt vil gvote rwe han
###### 1448 | ### Do sprach aber Wærbelin vnt moeht daz geschehen ### daz wir mine vrowen chonden ê gesæhen ### Vten di vil richen ê wir schveffen vns gemach ### Giselher der edele do vil zvehtechlichen sprach
| ### Daz sol iv niemen <wenden> welt ir fver si gan ### ir habt miner mvter willen gar getan ### want si sihet ivch gerne dvrch di swester min ### vrovn Criemhilden ir svlt ir wellechomen sin
###### 1450 | ### Giselher si brahte da er di vrowen vant ### di boten sach si gerne von der Hivnen lant ### si grvztes minnechliche dvrh ir tvgende mvt ### so sagten ir div mære di boten <hoffsh> vnde gvt
###### 1451 | ### Ia enbivtet iv min vrowe so sprach Swemmelin ### dienest vnde triwe mohte daz gesin ### daz si ivch diche sæhe ir svlt gelovben daz ### so wær ir in der werlde mit deheinen vrevden baz
| ### Do sprach div chveneginne des enmach [362b] niht gesin ### swie gerne ich dicke sæhe di lieben tohter min ### so ist mir leider ce verre des edeln chveneges wip ### nv si immer sælich ir vnd Eceln lip
###### 1453 | ### Ir svlt mich lazen wizen ê irz gervmet hie ### wenne ir wider wellet ine gesach so gerne nie ### boten in langen ziten denne ich ivch han gesæhen ### di chnappen ir do lobten daz si daz liezen geschehen
###### 1454 | ### Zen herbergen fvren di von Hivnen lant ### do het der kvenech riche nach frivnden sin gesant ### Gventher der edele vragte sine man ### wi in div rede geviele vil maniger do sprechen began
| ### Daz er wol moehte riten in Eceln lant ### daz rieten im di besten di er da vnder vant ### ane Hagen eine dem was ez grimme leit ### er sprach zem kvenige tovgen ir habt iv selben wider seit
###### 1456 | ### Nv ist iv doch gewizen waz wir haben getan ### wir mvegen immer sorge zv Criemhilde han ### wand ich slvch ze tode ir man mit miner hant ### wie getorste wir riten in daz Eceln lant
###### 1457 | ### Do sprach der kvnech riche min swester lie den zorn ### mit chvsse minnecliche si hat vf vns verchorn ### daz wir ir ie getaten ê si von hinnen reit ### ezen si et Hagen danne iv einem widerseit
| ### Nv lat ivch niht betragen sprach Hagene swes si iehen ### di boten von den Hivnen welt ir Criemhilde sehen ### ir mvegt da verliesen di ere vnd ovch den lip ### ia ist vil lanchræche des kvenech Eceln wip
###### 1459 | ### Do sprach zv dem rate der fverste Gernot ### sit ir von schvlden fverhtet da den tot ### in hivnisschen richen solde wirz dar vmbe lan ### wir ensæhen vnser swester daz wære vil vbele getan
###### 1460 | ### Do sprach der fverste <Giselher> zv dem degene ### sit ir ivch schvldech wizet frivnt Hagene ### so svlt ir hi beliben vnt ivch wol bewarn ### vnt lazet di getverren zv miner swester mit vns varn
| ### Do begonde zvernen von Tronege der degen ### ine wil daz ir iemen fverhtet vf den wegen ### der getverre riten mit iv ce hove baz ### sit ir niht welt erwinden ich sol iv wol erzeigen daz
###### 1462 | ### Do sprach der dvchenmeister Rvmolt [363a] der degen ### der vremden vnt der chvnden mohtet ir wol heizen pflegen ### nach iwer selbes willen wand ir habet vollen rat ### ich wæne niht daz Hagene ivch noch vergiselt hat
###### 1463 | ### Welt ir niht volgen Hagene iv rætet Rvmolt ### wand ich iv bin mit triwen vil dienestlichen holt ### daz ir svlt hi beliben dvrch den willen min ### vnde lat den kvenech Ecel dort bi Criemhilde sin
| ### Wi chvnde iv in der werlde immer sanfter wesen ### ir mvegt vor iwern finden harte wol genesen ### ir svlt mit gvten chleidern zieren wol den lip ### trinchet win den besten vnt minnet wærtlichiv wip
###### 1465 | ### Dar zv git man iv spise di besten di ê gewan ### in der werlt kvenech deheiner ob des niht moeht ergan ### ir soldet noh beliben dvrch iwer schoene wip ### ê ir so chintliche soldet wagen den lip
###### 1466 | ### Des rat ich beliben rich sint iwer lant ### man mach iv baz erloesen hie heime div pfant ### danne da cen Hivnen wer weiz wie iz da gestat ### ir svlt beliben herren daz ist der Rvmoldes rat
| ### Wir wellen niht beliben sprach do Gernot ### sit daz vns min swester so minnechlich enbot ### vnt Ecel der riche zwiv solde wir daz lan ### der dar niht gerne welle der mach hi heime bestan
###### 1468 | ### Des antwrte Hagene lat ivh vnblinden niht ### mine rede dar vmbe swi halt iv geschit ### ich rat iv an den triwen welt ir ivch bewarn ### so svlt ir zv den Hivnen vil gewærliche varn
###### 1469 | ### Sit ir niht welt erwinden so besendet iwer man ### di besten di ir vindet oder inder mveget han ### so wel ich vz in allen tvsent ritter gvt ### sone mag iv niht gewerren der argen Criemhilde mvt
| ### Des wil ich gerne volgen sprach der kvenech zehant ### do hiez er boten riten witen in siniv lant ### do brahte man der helde driv tvsent oder mer ### sine wanden niht cerwerben also grozlichiv ser
###### 1471 | ### Si ritten vroeliche in Gventheres lant ### man hiez in allen geben ross vnt ovh gewant ### di da varen solden von Bvergonden dan ### der kvenech mit gvtem willen der vil manegen gewan
###### 1472 | ### Do hiez von Tronege Hagene Danchwart der brvder sin ### ir beider rech [363b] en ahzech fveren an den Rin ### di chomen ritterliche harnassh vnt gewant ### fvrten di vil snellen in daz Gvntheres lant
| ### Do chom der chvene Volker ein edel spilman ### zv der hovereise mit drizech siner man ### di heten soelech gewæte ez moeht ein chvenech tragen ### daz er zen Hivnen wolde daz hiez er Gventhere sagen
###### 1474 | ### Wer der Volker wære daz wil ich <ivch> wizen lan ### er was ein edel herre im was ovch vndertan ### vil der gvten rechen in Bvrgonden lant ### dvrch daz er videln chonde do was <er> der spilman genant
###### 1475 | ### Hagne welte tvsent di het er wol bechant ### vnt swaz in starchn striten gefrvemt het ir hant ### oder swaz si ie begiengen des het er vil gesehen ### den chonde anders niemen niwan frvemcheite iehen
| ### Di boten Criemhilde vil sere da verdroz ### wande ir vorhte cir herren div was harte groz ### si gerten tægeliche vrlovbes von dan ### des en gonde in niht Hagene daz was dvrch liste getan
###### 1477 | ### Er sprach zv sinem herren wir sveln daz bewarn ### daz wir si lazen riten ê daz wir selbe varn ### dar nach in siben tagen in Eceln lant ### treit vns iemen argen villen deist vns deste baz bechant
###### 1478 | ### Sone mach ovch sich vrov Criemhilt bereiten niht dar zv ### daz vns dvrh ir rate iemen schaden tv ### hat aber si den willen ez mach ir leide ergan ### wir fveren mit vns hinnen so manigen vz erwelten man
| ### Schilde vnd sætele vnt allez ir gewant ### daz si fveren wolden in Eceln lant ### daz was bereitet nv gar vil manigem chvenem man ### di boten Criemhilde hiez man fver Gvntheren gan
###### 1480 | ### Do di boten chomen do sprach Gernot ### der kvenech wil gevolgen des vns Ecel her enbot ### wir wellen chomen gerne ce siner hohgecit ### vnd sehen vnser swester daz ir des ane zwifel sit
###### 1481 | ### Do sprach der kvenech Gventher chvennet ir vns gesagen ### wenne si div hohzit oder in welhen tagen ### wir dar chomen solden do sprach Swemmelin [364a] ### cen næhesten svenewenden sol si wærliche sin
| ### Der kvenich in erlovbte des was noh niht geschehen ### ob si wolden gerne frvon Prvennhilde sehen ### daz si fver si solden mit sinem willen gan ### daz vnderstvnt do Volker daz was ir liebe getan
###### 1483 | ### Iane ist min vrowe Prvennhilt nv niht so wol gemvt ### daz ir si mveget schowen sprach der ritter gvt ### bitet vnz morgn so lat mans ivch sehen ### do si sie wanden schowen done chvndes niht geschehen
###### 1484 | ### Do hiez der fverste <riche> er was den boten holt ### dvrch sine selbes tvgende tragen dar sin golt ### vffe den breiten schilden der moht er vile han ### ovch wart in richiv gabe von sinen vrivnden getan
| ### Giselher vnd Gernot Gere vnd Oertwin ### daz si ovch milte waren daz taten si wol shin ### also riche gabe bvten si di boten an ### daz si se vor ir herren niht getorsten enpfan
###### 1486 | ### Do sprach zv dem kvenige der bote Wærbelin ### her kvenich lat iwer gabe hi ze lande sin ### wir mvegen ir doch niht fveren min herre iz vns verbot ### daz wir iht gabe næmen ovch ist es harte lvecel not
###### 1487 | ### Do wart der vogt von Rine da von vil vngemvt ### daz si versprechen wolden so riches kveneges gvt ### doch mvosen si enpfahen sin golt vnd sin gewant ### daz si mit in fvorten sit in Ecelen lant
| ### Si wolden sehen Vten ê si schieden dan ### Giselher der snelle der braht di spileman ### fver sine mvoter Vten div vrowe enbot von dan ### swaz si ern hete daz wær ir liebe getan
###### 1389 | ### Do hiez div chveneginne ir porten vnd ir golt ### geben dvrch Criemhilde want der was si holt ### vnt dvrch den kvenech Ecel den selben spileman ### si mohtenz gern enpfahen ez was mit triwen getan
###### 1490 | ### Vrlovp genomen heten di boten nv von dan ### von wiben vnd von mannen vroelich si do dan ### fvoren in ce Swaben dar hiez si Gernot ### sine helde leiten daz ez in niemen missebot
| ### Do sich di von in schieden di ir solden pflegen ### herschaft div Eceln vridet vf allen wegen ### des en nam in niemen ross noch ir gewant ### si ilten harte balde in daz Ecelen lant
###### 1492 | ### Swa si der vrivnt iht wessen daz taten si den chvnt ### daz di Bvrgonden in vil [364b] chvrzer stvnt ### choemen her von Rine in der Hivnen lant ### dem bissoffe Pilgerime wart ovch daz mære bechant
###### 1493 | ### Da si fver Bechelaren di straze nider ritten ### man saget ez Rvedger daz enwart niht vermitten ### vnde Gotelinde des margraven wip ### daz si sehen solde des wart vil vroelich ir lip
| ### Gahen mit den mæren sah man di spilman ### Eceln si fvnden in dr stat ze Gran ### dienest veber dienest der man im vil enbot ### sageten si dem kvenige vor liebe wart er frevden rot
###### 1495 | ### Do div chveneginne div mære reht ervant ### daz ir brvder solden chomen in daz lant ### do was ir wol ce mvte si lonte den spileman ### mit vil grozer gabe daz was ir ere getan
###### 1496 | ### Si sprach nv sagt beide Wærbel vnd Swemmelin ### welhe mine mage cer hohzit wellen sin ### der besten di wir ladeten her in dize lant ### nv sagt waz redete Hagene do er div mære bevant
| ### Er sprach der chom cer sprache an einem morgen frv ### lvecel gvter sprveche redet er der zv ### do si di reise lobten her in Hivnen lant ### daz was dem grimmem Hagene gar cem tode genant
###### 1498 | ### Ez chvment iwer brvder di chvenige alle dri ### in herlichem mvote swer mer da mite si ### der mære ich enedechlichen wizzen nine chan ### ez lobt mit in riten Volker der chvene spileman
###### 1499 | ### Des enbær ich harte lihte sprach des kveneges wip ### deich immer sæhe den Volkeres lip ### Hagenen bin ich wæge der ist ein helt vil gvt ### daz wir in sæhen mvezen des stat mir hohe der mvt
| ### Do gie div chveneginne da si den kvenech sach ### wi rehte minnechliche criemhilt do sprach ### wi gevallent iv div mære lieber herre min ### des ie min wille gerte daz sol nv verendet sin
###### 1501 | ### Din wille deist min vrevde sprach der kvenich do ### ine wart min selbes mage ni so rehte vro ### ob si iemer chomen solden her in miniv lant ### dvrh liebe diner frivnde so ist min sorge verswant
###### 1502 | ### Des chveneges ammetlivte di hiezen veber al ### mit gesidele rihten palas vnd sal ### gegen den lieben gesten di in da solden chomen ### sit wart von in dem chvenege vil michel weinen benomen [365a]

<<< Übersicht <<< vorige Seite nächste Seite >>>